/*
	File:		StdPrefsTester.r

	Contains:	Standard preferences component tester resources.

				Refer to develop Issue 18, "The Right Way to Implement 
				Preferences Files", for additional details on this code.
				
	Written by:	Gary Woodcock

	Copyright:	 1993-94 by Apple Computer, Inc.

	Change History (most recent first):
	
				  3/3/94	Version 1.0.
	
	Notes: 		This code uses Apple's Universal Interfaces for C.
	
				Send bug reports to Gary Woodcock at AOL: gwoodcock
				or Internet: gwoodcock@aol.com.
*/

#define SystemSevenOrLater 1
#define SystemSevenOrBetter	1

#define forRez 1

#include "BalloonTypes.r"
#include "SysTypes.r"
#include "Types.r"

#include "CompileFlags.h"
#include "StdPrefsTester.h"

resource 'vers' (1) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"1.0 (US),  Apple Computer, Inc. 1993"
};

resource 'vers' (2) {
	0x1,
	0x0,
	final,
	0x0,
	verUS,
	"1.0",
	"(for StdPrefsTester 1.0)"
};

resource 'BNDL' (kStdPrefsTesterBaseResID) {
	kStdPrefsTesterCreator,
	0,
	{	/* array TypeArray: 2 elements */
		/* [1] */
		'FREF',
		{	/* array IDArray: 1 element */
			/* [1] */
			0, kStdPrefsTesterBaseResID
		},
		/* [2] */
		'ICN#',
		{	/* array IDArray: 1 element */
			/* [1] */
			0, kStdPrefsTesterBaseResID
		}
	}
};

data kStdPrefsTesterCreator (0, "Owner resource") {
	$"A920 4170 706C 6520 436F 6D70 7574"            /*  Apple Compute */
	$"7652 2C20 496E 632E 2031 3939 332D 3934"       /* r, Inc. 1993-94 */
};

resource 'FREF' (kStdPrefsTesterBaseResID) {
	'APPL',
	0,
	""
};

resource 'BNDL' (kStdPrefsTesterBaseResID+1) {
	kDummyStdPrefsTesterCreator,
	1,
	{	/* array TypeArray: 2 elements */
		/* [1] */
		'FREF',
		{	/* array IDArray: 2 elements */
			/* [1] */
			0, kStdPrefsTesterBaseResID+1,
			/* [2] */
			1, kStdPrefsTesterBaseResID+2
		},
		/* [2] */
		'ICN#',
		{	/* array IDArray: 2 elements */
			/* [1] */
			0, kStdPrefsTesterBaseResID+1,
			/* [2] */
			1, kStdPrefsTesterBaseResID+1
		}
	}
};

data kDummyStdPrefsTesterCreator (1, "Owner resource") {
	$"A920 4170 706C 6520 436F 6D70 7574"            /*  Apple Compute */
	$"7652 2C20 496E 632E 2031 3939 332D 3934"       /* r, Inc. 1993-94 */
};

resource 'FREF' (kStdPrefsTesterBaseResID+1) {
	kDummyPrefsFileType,
	0,
	""
};

resource 'FREF' (kStdPrefsTesterBaseResID+2) {
	kBogusPrefsFileType,
	1,
	""
};

resource 'open' (kStdPrefsTesterBaseResID) {
	kStdPrefsTesterCreator,
	{
	}
};

resource 'kind' (kStdPrefsTesterBaseResID) {
	kStdPrefsTesterCreator,
	0,
	{
		'APPL', "StdPrefsTester"
	}
};

resource 'kind' (kStdPrefsTesterBaseResID+1) {
	kDummyStdPrefsTesterCreator,
	0,
	{
		kDummyPrefsFileType, "StdPrefsTester preferences document",
		kBogusPrefsFileType, "StdPrefsTester preferences document"
	}
};

resource 'DLOG' (kAboutDialogID) {
	{60, 92, 170, 312},
	dBoxProc,
	visible,
	goAway,
	0x0,
	kAboutDialogID,
	"About StdPrefsTester",
	alertPositionMainScreen
};

resource 'DITL' (kAboutDialogID) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{79, 73, 99, 147},
		Button {
			enabled,
			"So what!"
		},
		/* [2] */
		{79, 73, 99, 147},
		UserItem {
			disabled
		},
		/* [3] */
		{2, 3, 67, 216},
		StaticText {
			disabled,
			"A feeble test application for \nwringing"
			" out the standard \npreferences code"
			"  \nblame Gary Woodcock."
		}
	}
};

resource 'MENU' (kAppleID) {
	kAppleID,
	textMenuProc,
	allEnabled,
	enabled,
	apple,
	{	/* array: 2 elements */
		/* [1] */
		"About StdPrefsTester", noIcon, noKey, noMark, plain,
		/* [2] */
		"-", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (kFileID) {
	kFileID,
	textMenuProc,
	allEnabled,
	enabled,
	"File",
	{	/* array: 1 elements */
		/* [1] */
		"Quit", noIcon, "Q", noMark, plain
	}
};

resource 'MENU' (kEditID) {
	kEditID,
	textMenuProc,
	allEnabled,
	enabled,
	"Edit",
	{	/* array: 6 elements */
		/* [1] */
		"Undo", noIcon, "Z", noMark, plain,
		/* [2] */
		"-", noIcon, noKey, noMark, plain,
		/* [3] */
		"Cut", noIcon, "X", noMark, plain,
		/* [4] */
		"Copy", noIcon, "C", noMark, plain,
		/* [5] */
		"Paste", noIcon, "V", noMark, plain,
		/* [6] */
		"Clear", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (kTestID) {
	kTestID,
	textMenuProc,
	allEnabled,
	enabled,
	"Test",
	{	/* array: 11 elements */
		/* [1] */
		"New Preferences File", noIcon, noKey, noMark, plain,
		/* [2] */
		"Delete Preferences File", noIcon, noKey, noMark, plain,
		/* [3] */
		"Delete Preferences Folder", noIcon, noKey, noMark, plain,
		/* [4] */
		"-", noIcon, noKey, noMark, plain,
		/* [5] */
		"Get Preferences File Version 1", noIcon, noKey, noMark, plain,
		/* [6] */
		"Set Preferences File Version 1", noIcon, noKey, noMark, plain,
		/* [7] */
		"Get Preferences File Version 2", noIcon, noKey, noMark, plain,
		/* [8] */
		"Set Preferences File Version 2", noIcon, noKey, noMark, plain,
		/* [9] */
		"-", noIcon, noKey, noMark, plain,
		/* [10] */
		"Read Preference", noIcon, noKey, noMark, plain,
		/* [11] */
		"Write Preference", noIcon, noKey, noMark, plain
		/* [12] */
		"Delete Preference", noIcon, noKey, noMark, plain
	}
};

resource 'MBAR' (kMenuBarID) {
	{	/* array MenuArray: 4 elements */
		/* [1] */
		kAppleID,
		/* [2] */
		kFileID,
		/* [3] */
		kEditID,
		/* [4] */
		kTestID
	}
};

resource 'ICN#' (kStdPrefsTesterBaseResID) {
	{	/* array: 2 elements */
		/* [1] */
		$"0001 0000 0002 8000 0004 4000 0008 2000"
		$"0010 1000 0020 0800 0040 0400 0080 0200"
		$"0100 0100 0200 0080 0400 0040 0800 0020"
		$"1000 0010 2000 0008 4000 3F04 8000 4082"
		$"4000 8041 2001 3022 1001 C814 080E 7F8F"
		$"0402 3007 0201 0007 0100 8007 0080 6007"
		$"0040 1FE7 0020 021F 0010 0407 0008 0800"
		$"0004 1000 0002 2000 0001 4000 0000 80",
		/* [2] */
		$"0001 0000 0003 8000 0007 C000 000F E000"
		$"001F F000 003F F800 007F FC00 00FF FE00"
		$"01FF FF00 03FF FF80 07FF FFC0 0FFF FFE0"
		$"1FFF FFF0 3FFF FFF8 7FFF FFFC FFFF FFFE"
		$"7FFF FFFF 3FFF FFFE 1FFF FFFC 0FFF FFFF"
		$"07FF FFFF 03FF FFFF 01FF FFFF 00FF FFFF"
		$"007F FFFF 003F FE1F 001F FC07 000F F800"
		$"0007 F000 0003 E000 0001 C000 0000 80"
	}
};

resource 'icl8' (kStdPrefsTesterBaseResID) {
	$"0000 0000 0000 0000 0000 0000 0000 00FF"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 FFF5"
	$"FF00 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 00FF F5F5"
	$"F5FF 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 FFF5 F5F5"
	$"F5F5 FF00 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5FF 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5F5 FF00 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 00FF F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5FF 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 FFF5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 FF00 0000 0000 0000 0000"
	$"0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5FF 0000 0000 0000 0000"
	$"0000 0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 FF00 0000 0000 0000"
	$"0000 0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000 0000"
	$"0000 0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000"
	$"00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 FFFF FFFF FFFF F5F5 F5F5 F5FF 0000"
	$"FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5FF 0808 0808 0808 FFF5 F5F5 F5F5 FF00"
	$"00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"FF08 0808 0808 0808 08FF F5F5 F5F5 F5FF"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF"
	$"0808 FFFF 0808 0808 0808 FFF5 F5F5 FF00"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5FF"
	$"FFFF F5F5 FF08 0808 0808 08FF F5FF 0000"
	$"0000 0000 FFF5 F5F5 F5F5 F5F5 FFFF FF08"
	$"08FF FFFF FFFF FFFF FF08 0808 FFFF FFFF"
	$"0000 0000 00FF F5F5 F5F5 F5F5 F5F5 FF08"
	$"0808 FFFF 0808 0808 0808 0808 08FF FFFF"
	$"0000 0000 0000 FFF5 F5F5 F5F5 F5F5 F5FF"
	$"0808 0808 0808 0808 0808 0808 08FF FFFF"
	$"0000 0000 0000 00FF F5F5 F5F5 F5F5 F5F5"
	$"FF08 0808 0808 0808 0808 0808 08FF FFFF"
	$"0000 0000 0000 0000 FFF5 F5F5 F5F5 F5F5"
	$"F5FF FF08 0808 0808 0808 0808 08FF FFFF"
	$"0000 0000 0000 0000 00FF F5F5 F5F5 F5F5"
	$"F5F5 F5FF FFFF FFFF FFFF FF08 08FF FFFF"
	$"0000 0000 0000 0000 0000 FFF5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 FF00 0000 00FF FFFF FFFF"
	$"0000 0000 0000 0000 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5FF 0000 0000 0000 00FF FFFF"
	$"0000 0000 0000 0000 0000 0000 FFF5 F5F5"
	$"F5F5 F5F5 FF00 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 00FF F5F5"
	$"F5F5 F5FF 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 FFF5"
	$"F5F5 FF00 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 00FF"
	$"F5FF 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"FF"
};

resource 'icl4' (kStdPrefsTesterBaseResID) {
	$"0000 0000 0000 000F 0000 0000 0000 0000"
	$"0000 0000 0000 00FC F000 0000 0000 0000"
	$"0000 0000 0000 0FC0 CF00 0000 0000 0000"
	$"0000 0000 0000 FC0C 0CF0 0000 0000 0000"
	$"0000 0000 000F C0C0 C0CF 0000 0000 0000"
	$"0000 0000 00FC 0C0C 0C0C F000 0000 0000"
	$"0000 0000 0FC0 C0C0 C0C0 CF00 0000 0000"
	$"0000 0000 FC0C 0C0C 0C0C 0CF0 0000 0000"
	$"0000 000F C0C0 C0C0 C0C0 C0CF 0000 0000"
	$"0000 00FC 0C0C 0C0C 0C0C 0C0C F000 0000"
	$"0000 0FC0 C0C0 C0C0 C0C0 C0C0 CF00 0000"
	$"0000 FC0C 0C0C 0C0C 0C0C 0C0C 0CF0 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000"
	$"00FC 0C0C 0C0C 0C0C 0C0C 0C0C 0C0C F000"
	$"0FC0 C0C0 C0C0 C0C0 C0FF FFFF C0C0 CF00"
	$"FC0C 0C0C 0C0C 0C0C 0F02 0202 FC0C 0CF0"
	$"0FC0 C0C0 C0C0 C0C0 F020 2020 2FC0 C0CF"
	$"00FC 0C0C 0C0C 0C0F 02FF 0202 02FC 0CF0"
	$"000F C0C0 C0C0 C0CF FFC0 F020 202F CF00"
	$"0000 FC0C 0C0C FFF2 0FFF FFFF F202 FFFF"
	$"0000 0FC0 C0C0 C0F0 20FF 2020 2020 2FFF"
	$"0000 00FC 0C0C 0C0F 0202 0202 0202 0FFF"
	$"0000 000F C0C0 C0C0 F020 2020 2020 2FFF"
	$"0000 0000 FC0C 0C0C 0FF2 0202 0202 0FFF"
	$"0000 0000 0FC0 C0C0 C0CF FFFF FFF0 2FFF"
	$"0000 0000 00FC 0C0C 0C0C 0CF0 000F FFFF"
	$"0000 0000 000F C0C0 C0C0 CF00 0000 0FFF"
	$"0000 0000 0000 FC0C 0C0C F000 0000 0000"
	$"0000 0000 0000 0FC0 C0CF 0000 0000 0000"
	$"0000 0000 0000 00FC 0CF0 0000 0000 0000"
	$"0000 0000 0000 000F CF00 0000 0000 0000"
	$"0000 0000 0000 0000 F0"
};

resource 'ics#' (kStdPrefsTesterBaseResID) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 0100 0280 0440 0820 1010 2008 4064"
		$"8092 414E 26F6 1106 08FE 0446 0280 01",
		/* [2] */
		$"0000 0100 0380 07C0 0FE0 1FF0 3FF8 7FFC"
		$"FFFE 7FFE 3FFE 1FFE 0FFE 07C6 0380 01"
	}
};

resource 'ics8' (kStdPrefsTesterBaseResID) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 00FF 0000 0000 0000 0000"
	$"0000 0000 0000 FFF5 FF00 0000 0000 0000"
	$"0000 0000 00FF F5F5 F5FF 0000 0000 0000"
	$"0000 0000 FFF5 F5F5 F5F5 FF00 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 FFF5 F5F5 F5F5 F5F5 F5F5 FF00 0000"
	$"00FF F5F5 F5F5 F5F5 F5FF FFF5 F5FF 0000"
	$"FFF5 F5F5 F5F5 F5F5 FF08 08FF F5F5 FF00"
	$"00FF F5F5 F5F5 F5FF 08FF 0808 FFFF FF00"
	$"0000 FFF5 F5FF FF08 FFFF FFFF 08FF FF00"
	$"0000 00FF F5F5 F5FF 0808 0808 08FF FF00"
	$"0000 0000 FFF5 F5F5 FFFF FFFF FFFF FF00"
	$"0000 0000 00FF F5F5 F5FF 0000 00FF FF00"
	$"0000 0000 0000 FFF5 FF00 0000 0000 0000"
	$"0000 0000 0000 00FF"
};

resource 'ics4' (kStdPrefsTesterBaseResID) {
	$"0000 0000 0000 0000 0000 000F 0000 0000"
	$"0000 00F0 F000 0000 0000 0F0C 0F00 0000"
	$"0000 F0C0 C0F0 0000 000F 0C0C 0C0F 0000"
	$"00F0 C0C0 C0C0 F000 0F0C 0C0C 0FFC 0F00"
	$"F0C0 C0C0 F02F C0F0 0F0C 0C0F 2F02 FFF0"
	$"00F0 CFF0 FFFF 2FF0 000F 0C0F 0202 0FF0"
	$"0000 F0C0 FFFF FFF0 0000 0F0C 0F00 0FF0"
	$"0000 00F0 F000 0000 0000 000F"
};

resource 'ICN#' (kStdPrefsTesterBaseResID+1, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"1FFF F800 1000 0C00 1000 0A00 1000 0900"
		$"1000 0880 1000 0840 1000 0820 1000 0FF0"
		$"1000 0010 10E0 0010 1110 0010 12E8 0010"
		$"12E9 F790 12E8 0010 1110 0010 10E0 0010"
		$"1000 0010 1000 0010 1000 0010 1000 0010"
		$"1000 0010 10E0 0010 1110 0010 1208 0010"
		$"1209 EF90 1208 0010 1110 0010 10E0 0010"
		$"1000 0010 1000 0010 1000 0010 1FFF FFF0",
		/* [2] */
		$"1FFF F800 1FFF FC00 1FFF FE00 1FFF FF00"
		$"1FFF FF80 1FFF FFC0 1FFF FFE0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
		$"1FFF FFF0 1FFF FFF0 1FFF FFF0 1FFF FFF0"
	}
};

resource 'icl8' (kStdPrefsTesterBaseResID+1, purgeable) {
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF 0000 0000 0000 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FF2B FF00 0000 0000 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FF2B 2BFF 0000 0000 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FF2B 2B2B FF00 0000 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FF2B 2B2B 2BFF 0000 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FF2B 2B2B 2B2B FF00 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF FFFF FFFF FFFF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 FFFF FFF5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5FF 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 FF00 FFFF FF00 FFF5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 FF00 FFFF FF00 FFF5 F5FF"
	$"FFFF FFFF F5FF FFFF FFF5 F5FF 0000 0000"
	$"0000 00FF F5F5 FF00 FFFF FF00 FFF5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5FF 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 FFFF FFF5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 FFFF FFF5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5FF 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 FF00 0000 0000 FFF5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 FF00 0000 0000 FFF5 F5FF"
	$"FFFF FFF5 FFFF FFFF FFF5 F5FF 0000 0000"
	$"0000 00FF F5F5 FF00 0000 0000 FFF5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5FF 0000 00FF F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 FFFF FFF5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000 0000"
	$"0000 00FF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'icl4' (kStdPrefsTesterBaseResID+1, purgeable) {
	$"000F FFFF FFFF FFFF FFFF F000 0000 0000"
	$"000F 0C0C 0C0C 0C0C 0C0C FF00 0000 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 FCF0 0000 0000"
	$"000F 0C0C 0C0C 0C0C 0C0C FCCF 0000 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 FCCC F000 0000"
	$"000F 0C0C 0C0C 0C0C 0C0C FCCC CF00 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 FCCC CCF0 0000"
	$"000F 0C0C 0C0C 0C0C 0C0C FFFF FFFF 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0C0C FFFC 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0CF 000F C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0CF0 FFF0 FC0C 0C0C 0C0C 0C0F 0000"
	$"000F C0F0 FFF0 F0CF FFFF CFFF F0CF 0000"
	$"000F 0CF0 FFF0 FC0C 0C0C 0C0C 0C0F 0000"
	$"000F C0CF 000F C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0C0C FFFC 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0C0C 0C0C 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0C0C 0C0C 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0C0C FFFC 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0CF 000F C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0CF0 0000 FC0C 0C0C 0C0C 0C0F 0000"
	$"000F C0F0 0000 F0CF FFF0 FFFF F0CF 0000"
	$"000F 0CF0 0000 FC0C 0C0C 0C0C 0C0F 0000"
	$"000F C0CF 000F C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0C0C FFFC 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000"
	$"000F 0C0C 0C0C 0C0C 0C0C 0C0C 0C0F 0000"
	$"000F C0C0 C0C0 C0C0 C0C0 C0C0 C0CF 0000"
	$"000F FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'ics#' (kStdPrefsTesterBaseResID+1, purgeable) {
	{	/* array: 2 elements */
		/* [1] */
		$"7FE0 4030 4028 403C 4604 4F04 4F74 4604"
		$"4004 4004 4604 4904 4974 4604 4004 7FFC",
		/* [2] */
		$"7FE0 7FF0 7FF8 7FFC 7FFC 7FFC 7FFC 7FFC"
		$"7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC 7FFC"
	}
};

resource 'ics8' (kStdPrefsTesterBaseResID+1, purgeable) {
	$"00FF FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"00FF F5F5 F5F5 F5F5 F5F5 FFFF 0000 0000"
	$"00FF F5F5 F5F5 F5F5 F5F5 FF2B FF00 0000"
	$"00FF F5F5 F5F5 F5F5 F5F5 FFFF FFFF 0000"
	$"00FF F5F5 F5FF FFF5 F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 FFFF FFFF F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 FFFF FFFF F5FF FFFF F5FF 0000"
	$"00FF F5F5 F5FF FFF5 F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 F5FF FFF5 F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 FF00 00FF F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 FF00 00FF F5FF FFFF F5FF 0000"
	$"00FF F5F5 F5FF FFF5 F5F5 F5F5 F5FF 0000"
	$"00FF F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 0000"
	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'ics4' (kStdPrefsTesterBaseResID+1, purgeable) {
	$"0FFF FFFF FFF0 0000 0F0C 0C0C 0CFF 0000"
	$"0FC0 C0C0 C0FC F000 0F0C 0C0C 0CFF FF00"
	$"0FC0 CFF0 C0C0 CF00 0F0C FFFF 0C0C 0F00"
	$"0FC0 FFFF CFFF CF00 0F0C 0FFC 0C0C 0F00"
	$"0FC0 C0C0 C0C0 CF00 0F0C 0C0C 0C0C 0F00"
	$"0FC0 CFF0 C0C0 CF00 0F0C F00F 0C0C 0F00"
	$"0FC0 F00F CFFF CF00 0F0C 0FFC 0C0C 0F00"
	$"0FC0 C0C0 C0C0 CF00 0FFF FFFF FFFF FF"
};

#undef forRez
